@@ -35,7 +35,9 @@ output$ui_cmb_by <- renderUI({
   x <- varnames()
   y <- colnames(r_data[[input$cmb_y]])
   vars <- intersect(x, y)
-  if (length(vars) == 0) return()
+  if (length(vars) == 0) {
+    return()
+  }
   vars <- x[x %in% vars] ## need variable labels from varnames()
   selectInput(
     "cmb_by",
@@ -88,13 +90,14 @@ output$ui_Combine <- renderUI({
       uiOutput("ui_cmb_by"),
       uiOutput("ui_cmb_add"),
       selectInput(
-        "cmb_type", "Combine type:", choices = cmb_type,
+        "cmb_type", "Combine type:",
+        choices = cmb_type,
         selected = state_single("cmb_type", cmb_type, "inner_join"),
         multiple = FALSE
       ),
       tags$table(
         tags$td(textInput("cmb_name", "Combined dataset:", paste0(input$dataset, "_cmb"))),
-        tags$td(uiOutput("ui_cmb_store"), style = "padding-top:30px;")
+        tags$td(uiOutput("ui_cmb_store"), class = "top")
       )
     ),
     help_and_report(
@@ -125,7 +128,7 @@ observeEvent(input$cmb_store, {
   }
 })
 
-observeEvent(input$combine_report, {
+combine_report <- function() {
   req(input$cmb_y)
   inp <- clean_args(cmb_inputs(), cmb_args)
   if (identical(inp$add, colnames(r_data[[input$cmb_y]]))) {
@@ -144,7 +147,7 @@ observeEvent(input$combine_report, {
     xcmd = xcmd,
     figs = FALSE
   )
-})
+}
 
 output$cmb_data1 <- renderText({
   req(input$dataset)
@@ -159,7 +162,7 @@ output$cmb_data2 <- renderText({
 
 output$cmb_possible <- renderText({
   req(length(r_info[["datasetlist"]]) > 1)
-  if (is_empty(input$cmb_by) && !is_empty(input$cmb_type) && grepl("_join", input$cmb_type)) {
+  if (radiant.data::is_empty(input$cmb_by) && !radiant.data::is_empty(input$cmb_type) && grepl("_join", input$cmb_type)) {
     "<h3>No matching variables selected</h3>"
   }
 })
@@ -167,7 +170,7 @@ output$cmb_possible <- renderText({
 output$cmb_data <- renderText({
   req(length(r_info[["datasetlist"]]) > 1)
   req(input$cmb_store) ## dependence is needed to update cmb_type when result doesn't change
-  if (is_empty(input$cmb_name)) {
+  if (radiant.data::is_empty(input$cmb_name)) {
     dataset <- paste0("cmb_", isolate(input$dataset))
   } else {
     dataset <- fix_names(input$cmb_name)
@@ -176,7 +179,7 @@ output$cmb_data <- renderText({
     }
   }
 
-  if (!is_empty(r_info[["cmb_error"]])) {
+  if (!radiant.data::is_empty(r_info[["cmb_error"]])) {
     HTML(paste0("</br><h4>Combining data failed. The error message was:</br></br>\"", r_info[["cmb_error"]], "\"</h4>"))
   } else if (!is.null(r_data[[dataset]])) {
     show_data_snippet(dataset, nshow = 15, title = paste0(
@@ -185,3 +188,18 @@ output$cmb_data <- renderText({
     ))
   }
 })
+
+observeEvent(input$combine_report, {
+  r_info[["latest_screenshot"]] <- NULL
+  combine_report()
+})
+
+observeEvent(input$combine_screenshot, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_combine_screenshot")
+})
+
+observeEvent(input$modal_combine_screenshot, {
+  combine_report()
+  removeModal()
+})
\ No newline at end of file
