@@ -24,7 +24,7 @@ output$ui_view_vars <- renderUI({
 output$ui_View <- renderUI({
   tagList(
     wellPanel(
-      actionLink("view_clear", "Clear settings", icon = icon("refresh"), style = "color:black"),
+      actionLink("view_clear", "Clear settings", icon = icon("sync"), style = "color:black"),
       uiOutput("ui_view_vars"),
       numericInput(
         "view_dec", "Decimals:",
@@ -33,7 +33,7 @@ output$ui_View <- renderUI({
       ),
       tags$table(
         tags$td(textInput("view_name", "Store filtered data as:", "", placeholder = "Provide data name")),
-        tags$td(actionButton("view_store", "Store", icon = icon("plus"), class = "btn-success"), style = "padding-top:30px;")
+        tags$td(actionButton("view_store", "Store", icon = icon("plus"), class = "btn-success"), class = "top")
       )
     ),
     help_and_report(
@@ -80,6 +80,8 @@ output$dataviewer <- DT::renderDataTable({
   req(available(input$view_vars))
   dat <- select_at(.get_data(), .vars = input$view_vars)
 
+  style <- if (exists("bslib_current_version") && "4" %in% bslib_current_version()) "bootstrap4" else "bootstrap"
+
   search <- r_state$dataviewer_state$search$search
   if (is.null(search)) search <- ""
   fbox <- if (nrow(dat) > 5e6) "none" else list(position = "top")
@@ -92,7 +94,8 @@ output$dataviewer <- DT::renderDataTable({
   ## for rounding
   isInt <- sapply(dat, function(x) is.integer(x))
   isDbl <- sapply(dat, is_double)
-  dec <- input$view_dec %>% {ifelse(is_empty(.) || . < 0, 3, round(., 0))}
+  dec <- input$view_dec %>%
+    (function(x) ifelse(radiant.data::is_empty(x) || x < 0, 3, round(x, 0)))
 
   withProgress(
     message = "Generating view table", value = 1,
@@ -109,7 +112,7 @@ output$dataviewer <- DT::renderDataTable({
       # extension = "KeyTable",
       escape = FALSE,
       # editable = TRUE,
-      style = "bootstrap",
+      style = style,
       options = list(
         stateSave = TRUE, ## maintains state
         searchCols = lapply(r_state$dataviewer_search_columns, function(x) list(search = x)),
@@ -135,8 +138,8 @@ output$dataviewer <- DT::renderDataTable({
       ## https://github.com/rstudio/DT/issues/146#issuecomment-534319155
       callback = DT::JS('$(window).on("unload", function() { table.state.clear(); })')
     ) %>%
-      {if (sum(isDbl) > 0) DT::formatRound(., names(isDbl)[isDbl], dec) else .} %>%
-      {if (sum(isInt) > 0) DT::formatRound(., names(isInt)[isInt], 0) else .}
+      (function(x) if (sum(isDbl) > 0) DT::formatRound(x, names(isDbl)[isDbl], dec) else x) %>%
+      (function(x) if (sum(isInt) > 0) DT::formatRound(x, names(isInt)[isInt], 0) else x)
   )
 })
 
@@ -150,7 +153,8 @@ observeEvent(input$view_store, {
   }
 
   r_data[[dataset]] <- get_data(
-    input$dataset, vars = input$view_vars, filt = data_filter,
+    input$dataset,
+    vars = input$view_vars, filt = data_filter,
     rows = input$dataviewer_rows_all, na.rm = FALSE, envir = r_data
   )
   register(dataset)
@@ -168,7 +172,7 @@ observeEvent(input$view_store, {
                   con on the bottom left of your screen.")
         ),
         footer = modalButton("OK"),
-        size = "s",
+        size = "m",
         easyClose = TRUE
       )
     )
@@ -197,7 +201,7 @@ download_handler(id = "dl_view_tab", fun = dl_view_tab, fn = function() paste0(i
   ## get the state of the dt table
   ts <- dt_state("dataviewer", vars = input$view_vars)
 
-  if (is_empty(input$view_name)) {
+  if (radiant.data::is_empty(input$view_name)) {
     dataset <- NULL
   } else {
     dataset <- fix_names(input$view_name)
@@ -223,40 +227,40 @@ download_handler(id = "dl_view_tab", fun = dl_view_tab, fn = function() paste0(i
     vars <- paste0(vars, collapse = ", ")
   }
 
-  if (is_empty(dataset)) {
+  if (radiant.data::is_empty(dataset)) {
     xcmd <- paste0("  dtab(")
   } else {
     xcmd <- paste0("# dtab(", dataset, ", ")
   }
-  if (!is_empty(input$view_dec, 3)) {
+  if (!radiant.data::is_empty(input$view_dec, 3)) {
     xcmd <- paste0(xcmd, "dec = ", input$view_dec, ", ")
   }
-  if (!is_empty(r_state$dataviewer_state$length, 10)) {
+  if (!radiant.data::is_empty(r_state$dataviewer_state$length, 10)) {
     xcmd <- paste0(xcmd, "pageLength = ", r_state$dataviewer_state$length, ", ")
   }
   xcmd <- paste0(xcmd, "nr = 100) %>% render()")
 
   ## create the command to filter and sort the data
-  if (is_empty(dataset)) {
+  if (radiant.data::is_empty(dataset)) {
     cmd <- paste0(cmd, "## filter and sort the dataset\n", input$dataset)
   } else {
     cmd <- paste0(cmd, "## filter and sort the dataset\n", dataset, " <- ", input$dataset)
   }
-  if (input$show_filter && !is_empty(input$data_filter)) {
+  if (input$show_filter && !radiant.data::is_empty(input$data_filter)) {
     cmd <- paste0(cmd, " %>%\n  filter(", input$data_filter, ")")
   }
-  if (!is_empty(ts$search)) {
+  if (!radiant.data::is_empty(ts$search)) {
     cmd <- paste0(cmd, " %>%\n  filter(search_data(., \"", ts$search, "\"))")
   }
-  if (!is_empty(ts$tabfilt)) {
+  if (!radiant.data::is_empty(ts$tabfilt)) {
     cmd <- paste0(cmd, " %>%\n  filter(", ts$tabfilt, ")")
   }
-  if (!is_empty(ts$tabsort)) {
+  if (!radiant.data::is_empty(ts$tabsort)) {
     cmd <- paste0(cmd, " %>%\n  arrange(", ts$tabsort, ")")
   }
   ## moved `select` to the end so filters can use variables
   ## not selected for the final dataset
-  if (is_empty(dataset)) {
+  if (radiant.data::is_empty(dataset)) {
     paste0(cmd, " %>%\n  select(", vars, ") %>%") %>%
       paste0("\n", xcmd)
   } else {
@@ -268,6 +272,21 @@ download_handler(id = "dl_view_tab", fun = dl_view_tab, fn = function() paste0(i
   }
 }
 
-observeEvent(input$view_report, {
+view_report <- function() {
   update_report(cmd = .viewcmd(), outputs = NULL, figs = FALSE)
+}
+
+observeEvent(input$view_report, {
+  r_info[["latest_screenshot"]] <- NULL
+  view_report()
 })
+
+observeEvent(input$view_screenshot, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_view_screenshot")
+})
+
+observeEvent(input$modal_view_screenshot, {
+  view_report()
+  removeModal()
+})
\ No newline at end of file
